Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(478)

Unified Diff: third_party/pkg/angular/lib/directive/ng_bind_template.dart

Issue 256553002: Revert "Update all Angular libs (run update_all.sh)." (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/pkg/angular/lib/directive/ng_bind_template.dart
diff --git a/third_party/pkg/angular/lib/directive/ng_bind_template.dart b/third_party/pkg/angular/lib/directive/ng_bind_template.dart
index db993a951d6f8f45683bbf547b7e9222f5122985..97c8715edbd037572c6fc417055a73916091601d 100644
--- a/third_party/pkg/angular/lib/directive/ng_bind_template.dart
+++ b/third_party/pkg/angular/lib/directive/ng_bind_template.dart
@@ -1,20 +1,20 @@
part of angular.directive;
/**
* The [NgBindTemplate] specifies that the element text content should
* be replaced with the interpolation of the template in the ngBindTemplate
* attribute. Unlike ngBind, the ngBindTemplate can contain multiple {{ }}
* expressions.
*/
-@Decorator(
- selector: '[ng-bind-template]',
- map: const {'ng-bind-template': '@bind'})
-class NgBindTemplate {
+@NgDirective(
+ selector: '[ng-bind-template]',
+ map: const {'ng-bind-template': '@bind'})
+class NgBindTemplateDirective {
final dom.Element element;
- NgBindTemplate(this.element);
+ NgBindTemplateDirective(this.element);
- void set bind(value) {
+ set bind(value) {
element.text = value;
}
}
@@ -1,20 +1,20 @@
part of angular.directive;
/**
- * The [NgBindTemplate] specifies that the element text content should
+ * The [NgBindTemplateDirective] specifies that the element text content should
* be replaced with the interpolation of the template in the ngBindTemplate
* attribute. Unlike ngBind, the ngBindTemplate can contain multiple {{ }}
« no previous file with comments | « third_party/pkg/angular/lib/directive/ng_bind_html.dart ('k') | third_party/pkg/angular/lib/directive/ng_class.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698